@@ -20,10 +20,12 @@ TpProxyPendingCall *tp_cli_channel_call_close (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_run_close (TpChannel *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_callback_for_get_channel_type) (TpChannel *proxy,
@@ -38,11 +40,13 @@ TpProxyPendingCall *tp_cli_channel_call_get_channel_type (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_run_get_channel_type (TpChannel *proxy,
     gint timeout_ms,
     gchar **out_Channel_Type,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_callback_for_get_handle) (TpChannel *proxy,
@@ -58,12 +62,14 @@ TpProxyPendingCall *tp_cli_channel_call_get_handle (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_run_get_handle (TpChannel *proxy,
     gint timeout_ms,
     guint *out_Target_Handle_Type,
     guint *out_Target_Handle,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_callback_for_get_interfaces) (TpChannel *proxy,
@@ -78,11 +84,13 @@ TpProxyPendingCall *tp_cli_channel_call_get_interfaces (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_run_get_interfaces (TpChannel *proxy,
     gint timeout_ms,
     gchar ***out_Interfaces,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_call_state_signal_callback_call_state_changed) (TpChannel *proxy,
@@ -108,11 +116,13 @@ TpProxyPendingCall *tp_cli_channel_interface_call_state_call_get_call_states (Tp
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_call_state_run_get_call_states (TpChannel *proxy,
     gint timeout_ms,
     GHashTable **out_States,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_chat_state_signal_callback_chat_state_changed) (TpChannel *proxy,
@@ -138,11 +148,13 @@ TpProxyPendingCall *tp_cli_channel_interface_chat_state_call_set_chat_state (TpC
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_chat_state_run_set_chat_state (TpChannel *proxy,
     gint timeout_ms,
     guint in_State,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_dtmf_callback_for_start_tone) (TpChannel *proxy,
@@ -158,12 +170,14 @@ TpProxyPendingCall *tp_cli_channel_interface_dtmf_call_start_tone (TpChannel *pr
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_dtmf_run_start_tone (TpChannel *proxy,
     gint timeout_ms,
     guint in_Stream_ID,
     guchar in_Event,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_dtmf_callback_for_stop_tone) (TpChannel *proxy,
@@ -178,11 +192,13 @@ TpProxyPendingCall *tp_cli_channel_interface_dtmf_call_stop_tone (TpChannel *pro
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_dtmf_run_stop_tone (TpChannel *proxy,
     gint timeout_ms,
     guint in_Stream_ID,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_destroyable_callback_for_destroy) (TpChannel *proxy,
@@ -196,10 +212,12 @@ TpProxyPendingCall *tp_cli_channel_interface_destroyable_call_destroy (TpChannel
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_destroyable_run_destroy (TpChannel *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_signal_callback_handle_owners_changed) (TpChannel *proxy,
@@ -277,12 +295,14 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_add_members (TpChannel *
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_add_members (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     const gchar *in_Message,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_all_members) (TpChannel *proxy,
@@ -299,13 +319,15 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_all_members (TpChann
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_all_members (TpChannel *proxy,
     gint timeout_ms,
     GArray **out_Members,
     GArray **out_Local_Pending,
     GArray **out_Remote_Pending,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_group_flags) (TpChannel *proxy,
@@ -320,11 +342,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_group_flags (TpChann
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_group_flags (TpChannel *proxy,
     gint timeout_ms,
     guint *out_Group_Flags,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_handle_owners) (TpChannel *proxy,
@@ -340,12 +364,14 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_handle_owners (TpCha
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_handle_owners (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_Handles,
     GArray **out_Owners,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_local_pending_members) (TpChannel *proxy,
@@ -360,11 +386,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_local_pending_member
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_local_pending_members (TpChannel *proxy,
     gint timeout_ms,
     GArray **out_Handles,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_local_pending_members_with_info) (TpChannel *proxy,
@@ -379,11 +407,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_local_pending_member
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_local_pending_members_with_info (TpChannel *proxy,
     gint timeout_ms,
     GPtrArray **out_Info,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_members) (TpChannel *proxy,
@@ -398,11 +428,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_members (TpChannel *
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_members (TpChannel *proxy,
     gint timeout_ms,
     GArray **out_Handles,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_remote_pending_members) (TpChannel *proxy,
@@ -417,11 +449,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_remote_pending_membe
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_remote_pending_members (TpChannel *proxy,
     gint timeout_ms,
     GArray **out_Handles,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_self_handle) (TpChannel *proxy,
@@ -436,11 +470,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_self_handle (TpChann
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_get_self_handle (TpChannel *proxy,
     gint timeout_ms,
     guint *out_Self_Handle,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_remove_members) (TpChannel *proxy,
@@ -456,12 +492,14 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_remove_members (TpChanne
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_remove_members (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     const gchar *in_Message,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_remove_members_with_reason) (TpChannel *proxy,
@@ -478,13 +516,15 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_remove_members_with_reas
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_group_run_remove_members_with_reason (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     const gchar *in_Message,
     guint in_Reason,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_hold_signal_callback_hold_state_changed) (TpChannel *proxy,
@@ -511,12 +551,14 @@ TpProxyPendingCall *tp_cli_channel_interface_hold_call_get_hold_state (TpChannel
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_hold_run_get_hold_state (TpChannel *proxy,
     gint timeout_ms,
     guint *out_HoldState,
     guint *out_Reason,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_hold_callback_for_request_hold) (TpChannel *proxy,
@@ -531,11 +573,13 @@ TpProxyPendingCall *tp_cli_channel_interface_hold_call_request_hold (TpChannel *
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_hold_run_request_hold (TpChannel *proxy,
     gint timeout_ms,
     gboolean in_Hold,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_media_signalling_signal_callback_new_session_handler) (TpChannel *proxy,
@@ -561,11 +605,13 @@ TpProxyPendingCall *tp_cli_channel_interface_media_signalling_call_get_session_h
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_media_signalling_run_get_session_handlers (TpChannel *proxy,
     gint timeout_ms,
     GPtrArray **out_Session_Handlers,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_messages_signal_callback_message_sent) (TpChannel *proxy,
@@ -614,13 +660,15 @@ TpProxyPendingCall *tp_cli_channel_interface_messages_call_send_message (TpChann
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_messages_run_send_message (TpChannel *proxy,
     gint timeout_ms,
     const GPtrArray *in_Message,
     guint in_Flags,
     gchar **out_Token,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_messages_callback_for_get_pending_message_content) (TpChannel *proxy,
@@ -637,13 +685,15 @@ TpProxyPendingCall *tp_cli_channel_interface_messages_call_get_pending_message_c
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_messages_run_get_pending_message_content (TpChannel *proxy,
     gint timeout_ms,
     guint in_Message_ID,
     const GArray *in_Parts,
     GHashTable **out_Content,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_password_signal_callback_password_flags_changed) (TpChannel *proxy,
@@ -669,11 +719,13 @@ TpProxyPendingCall *tp_cli_channel_interface_password_call_get_password_flags (T
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_password_run_get_password_flags (TpChannel *proxy,
     gint timeout_ms,
     guint *out_Password_Flags,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_password_callback_for_provide_password) (TpChannel *proxy,
@@ -689,12 +741,14 @@ TpProxyPendingCall *tp_cli_channel_interface_password_call_provide_password (TpC
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_interface_password_run_provide_password (TpChannel *proxy,
     gint timeout_ms,
     const gchar *in_Password,
     gboolean *out_Correct,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_interface_tube_signal_callback_tube_channel_state_changed) (TpChannel *proxy,
@@ -732,13 +786,15 @@ TpProxyPendingCall *tp_cli_channel_type_dbus_tube_call_offer (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_dbus_tube_run_offer (TpChannel *proxy,
     gint timeout_ms,
     GHashTable *in_parameters,
     guint in_access_control,
     gchar **out_address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_dbus_tube_callback_for_accept) (TpChannel *proxy,
@@ -754,12 +810,14 @@ TpProxyPendingCall *tp_cli_channel_type_dbus_tube_call_accept (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_dbus_tube_run_accept (TpChannel *proxy,
     gint timeout_ms,
     guint in_access_control,
     gchar **out_address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_file_transfer_signal_callback_file_transfer_state_changed) (TpChannel *proxy,
@@ -809,6 +867,7 @@ TpProxyPendingCall *tp_cli_channel_type_file_transfer_call_accept_file (TpChanne
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_file_transfer_run_accept_file (TpChannel *proxy,
     gint timeout_ms,
     guint in_Address_Type,
@@ -817,7 +876,8 @@ gboolean tp_cli_channel_type_file_transfer_run_accept_file (TpChannel *proxy,
     guint64 in_Offset,
     GValue **out_Address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_file_transfer_callback_for_provide_file) (TpChannel *proxy,
@@ -835,6 +895,7 @@ TpProxyPendingCall *tp_cli_channel_type_file_transfer_call_provide_file (TpChann
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_file_transfer_run_provide_file (TpChannel *proxy,
     gint timeout_ms,
     guint in_Address_Type,
@@ -842,7 +903,8 @@ gboolean tp_cli_channel_type_file_transfer_run_provide_file (TpChannel *proxy,
     const GValue *in_Access_Control_Param,
     GValue **out_Address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_room_list_signal_callback_got_rooms) (TpChannel *proxy,
@@ -877,11 +939,13 @@ TpProxyPendingCall *tp_cli_channel_type_room_list_call_get_listing_rooms (TpChan
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_room_list_run_get_listing_rooms (TpChannel *proxy,
     gint timeout_ms,
     gboolean *out_In_Progress,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_room_list_callback_for_list_rooms) (TpChannel *proxy,
@@ -895,10 +959,12 @@ TpProxyPendingCall *tp_cli_channel_type_room_list_call_list_rooms (TpChannel *pr
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_room_list_run_list_rooms (TpChannel *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_room_list_callback_for_stop_listing) (TpChannel *proxy,
@@ -912,10 +978,12 @@ TpProxyPendingCall *tp_cli_channel_type_room_list_call_stop_listing (TpChannel *
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_room_list_run_stop_listing (TpChannel *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_stream_tube_signal_callback_new_remote_connection) (TpChannel *proxy,
@@ -967,6 +1035,7 @@ TpProxyPendingCall *tp_cli_channel_type_stream_tube_call_offer (TpChannel *proxy
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_stream_tube_run_offer (TpChannel *proxy,
     gint timeout_ms,
     guint in_address_type,
@@ -974,7 +1043,8 @@ gboolean tp_cli_channel_type_stream_tube_run_offer (TpChannel *proxy,
     guint in_access_control,
     GHashTable *in_parameters,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_stream_tube_callback_for_accept) (TpChannel *proxy,
@@ -992,6 +1062,7 @@ TpProxyPendingCall *tp_cli_channel_type_stream_tube_call_accept (TpChannel *prox
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_stream_tube_run_accept (TpChannel *proxy,
     gint timeout_ms,
     guint in_address_type,
@@ -999,7 +1070,8 @@ gboolean tp_cli_channel_type_stream_tube_run_accept (TpChannel *proxy,
     const GValue *in_access_control_param,
     GValue **out_address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_streamed_media_signal_callback_stream_added) (TpChannel *proxy,
@@ -1071,11 +1143,13 @@ TpProxyPendingCall *tp_cli_channel_type_streamed_media_call_list_streams (TpChan
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_streamed_media_run_list_streams (TpChannel *proxy,
     gint timeout_ms,
     GPtrArray **out_Streams,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_streamed_media_callback_for_remove_streams) (TpChannel *proxy,
@@ -1090,11 +1164,13 @@ TpProxyPendingCall *tp_cli_channel_type_streamed_media_call_remove_streams (TpCh
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_streamed_media_run_remove_streams (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_Streams,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_streamed_media_callback_for_request_stream_direction) (TpChannel *proxy,
@@ -1110,12 +1186,14 @@ TpProxyPendingCall *tp_cli_channel_type_streamed_media_call_request_stream_direc
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_streamed_media_run_request_stream_direction (TpChannel *proxy,
     gint timeout_ms,
     guint in_Stream_ID,
     guint in_Stream_Direction,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_streamed_media_callback_for_request_streams) (TpChannel *proxy,
@@ -1132,13 +1210,15 @@ TpProxyPendingCall *tp_cli_channel_type_streamed_media_call_request_streams (TpC
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_streamed_media_run_request_streams (TpChannel *proxy,
     gint timeout_ms,
     guint in_Contact_Handle,
     const GArray *in_Types,
     GPtrArray **out_Streams,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_text_signal_callback_lost_message) (TpChannel *proxy,
@@ -1202,11 +1282,13 @@ TpProxyPendingCall *tp_cli_channel_type_text_call_acknowledge_pending_messages (
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_text_run_acknowledge_pending_messages (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_IDs,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_text_callback_for_get_message_types) (TpChannel *proxy,
@@ -1221,11 +1303,13 @@ TpProxyPendingCall *tp_cli_channel_type_text_call_get_message_types (TpChannel *
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_text_run_get_message_types (TpChannel *proxy,
     gint timeout_ms,
     GArray **out_Available_Types,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_text_callback_for_list_pending_messages) (TpChannel *proxy,
@@ -1241,12 +1325,14 @@ TpProxyPendingCall *tp_cli_channel_type_text_call_list_pending_messages (TpChann
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_text_run_list_pending_messages (TpChannel *proxy,
     gint timeout_ms,
     gboolean in_Clear,
     GPtrArray **out_Pending_Messages,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_text_callback_for_send) (TpChannel *proxy,
@@ -1262,12 +1348,14 @@ TpProxyPendingCall *tp_cli_channel_type_text_call_send (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_text_run_send (TpChannel *proxy,
     gint timeout_ms,
     guint in_Type,
     const gchar *in_Text,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_signal_callback_new_tube) (TpChannel *proxy,
@@ -1341,11 +1429,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_available_stream_tube_typ
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_get_available_stream_tube_types (TpChannel *proxy,
     gint timeout_ms,
     GHashTable **out_Available_Stream_Tube_Types,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_available_tube_types) (TpChannel *proxy,
@@ -1360,11 +1450,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_available_tube_types (TpC
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_get_available_tube_types (TpChannel *proxy,
     gint timeout_ms,
     GArray **out_Available_Tube_Types,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_list_tubes) (TpChannel *proxy,
@@ -1379,11 +1471,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_list_tubes (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_list_tubes (TpChannel *proxy,
     gint timeout_ms,
     GPtrArray **out_Tubes,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_offer_d_bus_tube) (TpChannel *proxy,
@@ -1400,13 +1494,15 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_offer_d_bus_tube (TpChannel *
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_offer_d_bus_tube (TpChannel *proxy,
     gint timeout_ms,
     const gchar *in_Service,
     GHashTable *in_Parameters,
     guint *out_Tube_ID,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_offer_stream_tube) (TpChannel *proxy,
@@ -1427,6 +1523,7 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_offer_stream_tube (TpChannel
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_offer_stream_tube (TpChannel *proxy,
     gint timeout_ms,
     const gchar *in_Service,
@@ -1437,7 +1534,8 @@ gboolean tp_cli_channel_type_tubes_run_offer_stream_tube (TpChannel *proxy,
     const GValue *in_Access_Control_Param,
     guint *out_Tube_ID,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_accept_d_bus_tube) (TpChannel *proxy,
@@ -1453,12 +1551,14 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_accept_d_bus_tube (TpChannel
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_accept_d_bus_tube (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
     gchar **out_Address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_accept_stream_tube) (TpChannel *proxy,
@@ -1477,6 +1577,7 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_accept_stream_tube (TpChannel
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_accept_stream_tube (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
@@ -1485,7 +1586,8 @@ gboolean tp_cli_channel_type_tubes_run_accept_stream_tube (TpChannel *proxy,
     const GValue *in_Access_Control_Param,
     GValue **out_Address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_close_tube) (TpChannel *proxy,
@@ -1500,11 +1602,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_close_tube (TpChannel *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_close_tube (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_d_bus_tube_address) (TpChannel *proxy,
@@ -1520,12 +1624,14 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_d_bus_tube_address (TpCha
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_get_d_bus_tube_address (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
     gchar **out_Address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_d_bus_names) (TpChannel *proxy,
@@ -1541,12 +1647,14 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_d_bus_names (TpChannel *p
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_get_d_bus_names (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
     GPtrArray **out_DBus_Names,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_stream_tube_socket_address) (TpChannel *proxy,
@@ -1563,13 +1671,15 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_stream_tube_socket_addres
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_channel_type_tubes_run_get_stream_tube_socket_address (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
     guint *out_Address_Type,
     GValue **out_Address,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 G_END_DECLS
