@@ -24,6 +24,17 @@ TpProxySignalConnection *tp_cli_connection_connect_to_new_channel (TpConnection
     GObject *weak_object,
     GError **error);
 
+typedef void (*tp_cli_connection_signal_callback_connection_error) (TpConnection *proxy,
+    const gchar *arg_Error,
+    GHashTable *arg_Details,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_connect_to_connection_error (TpConnection *proxy,
+    tp_cli_connection_signal_callback_connection_error callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_connection_signal_callback_status_changed) (TpConnection *proxy,
     guint arg_Status,
     guint arg_Reason,
@@ -46,10 +57,12 @@ TpProxyPendingCall *tp_cli_connection_call_connect (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_connect (TpConnection *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_disconnect) (TpConnection *proxy,
@@ -63,14 +76,16 @@ TpProxyPendingCall *tp_cli_connection_call_disconnect (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_disconnect (TpConnection *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_get_interfaces) (TpConnection *proxy,
-    const gchar **out0,
+    const gchar **out_Interfaces,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -81,15 +96,17 @@ TpProxyPendingCall *tp_cli_connection_call_get_interfaces (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_get_interfaces (TpConnection *proxy,
     gint timeout_ms,
-    gchar ***out0,
+    gchar ***out_Interfaces,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_get_protocol) (TpConnection *proxy,
-    const gchar *out0,
+    const gchar *out_Protocol,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -100,15 +117,17 @@ TpProxyPendingCall *tp_cli_connection_call_get_protocol (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_get_protocol (TpConnection *proxy,
     gint timeout_ms,
-    gchar **out0,
+    gchar **out_Protocol,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_get_self_handle) (TpConnection *proxy,
-    guint out0,
+    guint out_Self_Handle,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -119,15 +138,17 @@ TpProxyPendingCall *tp_cli_connection_call_get_self_handle (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_get_self_handle (TpConnection *proxy,
     gint timeout_ms,
-    guint *out0,
+    guint *out_Self_Handle,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_get_status) (TpConnection *proxy,
-    guint out0,
+    guint out_Status,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -138,11 +159,13 @@ TpProxyPendingCall *tp_cli_connection_call_get_status (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_get_status (TpConnection *proxy,
     gint timeout_ms,
-    guint *out0,
+    guint *out_Status,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_hold_handles) (TpConnection *proxy,
@@ -158,16 +181,18 @@ TpProxyPendingCall *tp_cli_connection_call_hold_handles (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_hold_handles (TpConnection *proxy,
     gint timeout_ms,
     guint in_Handle_Type,
     const GArray *in_Handles,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_inspect_handles) (TpConnection *proxy,
-    const gchar **out0,
+    const gchar **out_Identifiers,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -180,17 +205,19 @@ TpProxyPendingCall *tp_cli_connection_call_inspect_handles (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_inspect_handles (TpConnection *proxy,
     gint timeout_ms,
     guint in_Handle_Type,
     const GArray *in_Handles,
-    gchar ***out0,
+    gchar ***out_Identifiers,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_list_channels) (TpConnection *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Channel_Info,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -201,11 +228,13 @@ TpProxyPendingCall *tp_cli_connection_call_list_channels (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_list_channels (TpConnection *proxy,
     gint timeout_ms,
-    GPtrArray **out0,
+    GPtrArray **out_Channel_Info,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_release_handles) (TpConnection *proxy,
@@ -221,16 +250,18 @@ TpProxyPendingCall *tp_cli_connection_call_release_handles (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_release_handles (TpConnection *proxy,
     gint timeout_ms,
     guint in_Handle_Type,
     const GArray *in_Handles,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_request_channel) (TpConnection *proxy,
-    const gchar *out0,
+    const gchar *out_Object_Path,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -245,38 +276,42 @@ TpProxyPendingCall *tp_cli_connection_call_request_channel (TpConnection *proxy,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_request_channel (TpConnection *proxy,
     gint timeout_ms,
     const gchar *in_Type,
     guint in_Handle_Type,
     guint in_Handle,
     gboolean in_Suppress_Handler,
-    gchar **out0,
+    gchar **out_Object_Path,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_callback_for_request_handles) (TpConnection *proxy,
-    const GArray *out0,
+    const GArray *out_Handles,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
 TpProxyPendingCall *tp_cli_connection_call_request_handles (TpConnection *proxy,
     gint timeout_ms,
     guint in_Handle_Type,
-    const gchar **in_Names,
+    const gchar **in_Identifiers,
     tp_cli_connection_callback_for_request_handles callback,
     gpointer user_data,
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_run_request_handles (TpConnection *proxy,
     gint timeout_ms,
     guint in_Handle_Type,
-    const gchar **in_Names,
-    GArray **out0,
+    const gchar **in_Identifiers,
+    GArray **out_Handles,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_aliasing_signal_callback_aliases_changed) (TpConnection *proxy,
@@ -290,7 +325,7 @@ TpProxySignalConnection *tp_cli_connection_interface_aliasing_connect_to_aliases
     GError **error);
 
 typedef void (*tp_cli_connection_interface_aliasing_callback_for_get_alias_flags) (TpConnection *proxy,
-    guint out0,
+    guint out_Alias_Flags,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -301,15 +336,17 @@ TpProxyPendingCall *tp_cli_connection_interface_aliasing_call_get_alias_flags (T
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_aliasing_run_get_alias_flags (TpConnection *proxy,
     gint timeout_ms,
-    guint *out0,
+    guint *out_Alias_Flags,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_aliasing_callback_for_request_aliases) (TpConnection *proxy,
-    const gchar **out0,
+    const gchar **out_Aliases,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -321,16 +358,18 @@ TpProxyPendingCall *tp_cli_connection_interface_aliasing_call_request_aliases (T
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_aliasing_run_request_aliases (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
-    gchar ***out0,
+    gchar ***out_Aliases,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_aliasing_callback_for_get_aliases) (TpConnection *proxy,
-    GHashTable *out0,
+    GHashTable *out_Aliases,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -342,12 +381,14 @@ TpProxyPendingCall *tp_cli_connection_interface_aliasing_call_get_aliases (TpCon
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_aliasing_run_get_aliases (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
-    GHashTable **out0,
+    GHashTable **out_Aliases,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_aliasing_callback_for_set_aliases) (TpConnection *proxy,
@@ -362,11 +403,13 @@ TpProxyPendingCall *tp_cli_connection_interface_aliasing_call_set_aliases (TpCon
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_aliasing_run_set_aliases (TpConnection *proxy,
     gint timeout_ms,
     GHashTable *in_Aliases,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_signal_callback_avatar_updated) (TpConnection *proxy,
@@ -394,12 +437,12 @@ TpProxySignalConnection *tp_cli_connection_interface_avatars_connect_to_avatar_r
     GError **error);
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_get_avatar_requirements) (TpConnection *proxy,
-    const gchar **out0,
-    guint out1,
-    guint out2,
-    guint out3,
-    guint out4,
-    guint out5,
+    const gchar **out_MIME_Types,
+    guint out_Min_Width,
+    guint out_Min_Height,
+    guint out_Max_Width,
+    guint out_Max_Height,
+    guint out_Max_Bytes,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -410,16 +453,18 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_get_avatar_requirem
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_get_avatar_requirements (TpConnection *proxy,
     gint timeout_ms,
-    gchar ***out0,
-    guint *out1,
-    guint *out2,
-    guint *out3,
-    guint *out4,
-    guint *out5,
+    gchar ***out_MIME_Types,
+    guint *out_Min_Width,
+    guint *out_Min_Height,
+    guint *out_Max_Width,
+    guint *out_Max_Height,
+    guint *out_Max_Bytes,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_get_avatar_tokens) (TpConnection *proxy,
@@ -435,12 +480,14 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_get_avatar_tokens (
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_get_avatar_tokens (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     gchar ***out_Tokens,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_get_known_avatar_tokens) (TpConnection *proxy,
@@ -456,17 +503,19 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_get_known_avatar_to
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_get_known_avatar_tokens (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     GHashTable **out_Tokens,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_request_avatar) (TpConnection *proxy,
-    const GArray *out0,
-    const gchar *out1,
+    const GArray *out_Data,
+    const gchar *out_MIME_Type,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -478,13 +527,15 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_request_avatar (TpC
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_request_avatar (TpConnection *proxy,
     gint timeout_ms,
     guint in_Contact,
-    GArray **out0,
-    gchar **out1,
+    GArray **out_Data,
+    gchar **out_MIME_Type,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_request_avatars) (TpConnection *proxy,
@@ -499,11 +550,13 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_request_avatars (Tp
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_request_avatars (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_set_avatar) (TpConnection *proxy,
@@ -520,13 +573,15 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_set_avatar (TpConne
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_set_avatar (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Avatar,
     const gchar *in_MIME_Type,
     gchar **out_Token,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_avatars_callback_for_clear_avatar) (TpConnection *proxy,
@@ -540,12 +595,24 @@ TpProxyPendingCall *tp_cli_connection_interface_avatars_call_clear_avatar (TpCon
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_avatars_run_clear_avatar (TpConnection *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_balance_signal_callback_balance_changed) (TpConnection *proxy,
+    const GValueArray *arg_Balance,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_balance_connect_to_balance_changed (TpConnection *proxy,
+    tp_cli_connection_interface_balance_signal_callback_balance_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
 typedef void (*tp_cli_connection_interface_capabilities_signal_callback_capabilities_changed) (TpConnection *proxy,
     const GPtrArray *arg_Caps,
     gpointer user_data, GObject *weak_object);
@@ -557,7 +624,7 @@ TpProxySignalConnection *tp_cli_connection_interface_capabilities_connect_to_cap
     GError **error);
 
 typedef void (*tp_cli_connection_interface_capabilities_callback_for_advertise_capabilities) (TpConnection *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Self_Capabilities,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -570,17 +637,19 @@ TpProxyPendingCall *tp_cli_connection_interface_capabilities_call_advertise_capa
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_capabilities_run_advertise_capabilities (TpConnection *proxy,
     gint timeout_ms,
     const GPtrArray *in_Add,
     const gchar **in_Remove,
-    GPtrArray **out0,
+    GPtrArray **out_Self_Capabilities,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_capabilities_callback_for_get_capabilities) (TpConnection *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Contact_Capabilities,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -592,12 +661,167 @@ TpProxyPendingCall *tp_cli_connection_interface_capabilities_call_get_capabiliti
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_capabilities_run_get_capabilities (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Handles,
-    GPtrArray **out0,
+    GPtrArray **out_Contact_Capabilities,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_capabilities_signal_callback_contact_capabilities_changed) (TpConnection *proxy,
+    GHashTable *arg_caps,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_capabilities_connect_to_contact_capabilities_changed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_capabilities_signal_callback_contact_capabilities_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_capabilities_callback_for_update_capabilities) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_capabilities_call_update_capabilities (TpConnection *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Handler_Capabilities,
+    tp_cli_connection_interface_contact_capabilities_callback_for_update_capabilities callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_capabilities_run_update_capabilities (TpConnection *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_Handler_Capabilities,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_capabilities_callback_for_get_contact_capabilities) (TpConnection *proxy,
+    GHashTable *out_Contact_Capabilities,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_capabilities_call_get_contact_capabilities (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Handles,
+    tp_cli_connection_interface_contact_capabilities_callback_for_get_contact_capabilities callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_capabilities_run_get_contact_capabilities (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Handles,
+    GHashTable **out_Contact_Capabilities,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_info_signal_callback_contact_info_changed) (TpConnection *proxy,
+    guint arg_Contact,
+    const GPtrArray *arg_ContactInfo,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_contact_info_connect_to_contact_info_changed (TpConnection *proxy,
+    tp_cli_connection_interface_contact_info_signal_callback_contact_info_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_contact_info_callback_for_get_contact_info) (TpConnection *proxy,
+    GHashTable *out_ContactInfo,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_info_call_get_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_info_callback_for_get_contact_info callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_info_run_get_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GHashTable **out_ContactInfo,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_info_callback_for_refresh_contact_info) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_info_call_refresh_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_contact_info_callback_for_refresh_contact_info callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_info_run_refresh_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_info_callback_for_request_contact_info) (TpConnection *proxy,
+    const GPtrArray *out_Contact_Info,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_info_call_request_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    tp_cli_connection_interface_contact_info_callback_for_request_contact_info callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_info_run_request_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    GPtrArray **out_Contact_Info,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_contact_info_callback_for_set_contact_info) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contact_info_call_set_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_ContactInfo,
+    tp_cli_connection_interface_contact_info_callback_for_set_contact_info callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_contact_info_run_set_contact_info (TpConnection *proxy,
+    gint timeout_ms,
+    const GPtrArray *in_ContactInfo,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_contacts_callback_for_get_contact_attributes) (TpConnection *proxy,
@@ -615,6 +839,7 @@ TpProxyPendingCall *tp_cli_connection_interface_contacts_call_get_contact_attrib
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_contacts_run_get_contact_attributes (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Handles,
@@ -622,7 +847,86 @@ gboolean tp_cli_connection_interface_contacts_run_get_contact_attributes (TpConn
     gboolean in_Hold,
     GHashTable **out_Attributes,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_location_signal_callback_location_updated) (TpConnection *proxy,
+    guint arg_Contact,
+    GHashTable *arg_Location,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_connection_interface_location_connect_to_location_updated (TpConnection *proxy,
+    tp_cli_connection_interface_location_signal_callback_location_updated callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_connection_interface_location_callback_for_get_locations) (TpConnection *proxy,
+    GHashTable *out_Locations,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_location_call_get_locations (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    tp_cli_connection_interface_location_callback_for_get_locations callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_location_run_get_locations (TpConnection *proxy,
+    gint timeout_ms,
+    const GArray *in_Contacts,
+    GHashTable **out_Locations,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_location_callback_for_request_location) (TpConnection *proxy,
+    GHashTable *out_Location,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_location_call_request_location (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    tp_cli_connection_interface_location_callback_for_request_location callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_location_run_request_location (TpConnection *proxy,
+    gint timeout_ms,
+    guint in_Contact,
+    GHashTable **out_Location,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
+
+
+typedef void (*tp_cli_connection_interface_location_callback_for_set_location) (TpConnection *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_location_call_set_location (TpConnection *proxy,
+    gint timeout_ms,
+    GHashTable *in_Location,
+    tp_cli_connection_interface_location_callback_for_set_location callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+#ifndef TP_DISABLE_DEPRECATED
+gboolean tp_cli_connection_interface_location_run_set_location (TpConnection *proxy,
+    gint timeout_ms,
+    GHashTable *in_Location,
+    GError **error,
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_signal_callback_presence_update) (TpConnection *proxy,
@@ -648,12 +952,14 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_add_status (TpConn
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_add_status (TpConnection *proxy,
     gint timeout_ms,
     const gchar *in_Status,
     GHashTable *in_Parameters,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_clear_status) (TpConnection *proxy,
@@ -667,10 +973,12 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_clear_status (TpCo
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_clear_status (TpConnection *proxy,
     gint timeout_ms,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_get_presence) (TpConnection *proxy,
@@ -686,16 +994,18 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_get_presence (TpCo
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_get_presence (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     GHashTable **out_Presence,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_get_statuses) (TpConnection *proxy,
-    GHashTable *out0,
+    GHashTable *out_Available_Statuses,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -706,11 +1016,13 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_get_statuses (TpCo
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_get_statuses (TpConnection *proxy,
     gint timeout_ms,
-    GHashTable **out0,
+    GHashTable **out_Available_Statuses,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_remove_status) (TpConnection *proxy,
@@ -725,11 +1037,13 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_remove_status (TpC
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_remove_status (TpConnection *proxy,
     gint timeout_ms,
     const gchar *in_Status,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_request_presence) (TpConnection *proxy,
@@ -744,11 +1058,13 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_request_presence (
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_request_presence (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_set_last_activity_time) (TpConnection *proxy,
@@ -763,11 +1079,13 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_set_last_activity_
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_set_last_activity_time (TpConnection *proxy,
     gint timeout_ms,
     guint in_Time,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_presence_callback_for_set_status) (TpConnection *proxy,
@@ -782,11 +1100,13 @@ TpProxyPendingCall *tp_cli_connection_interface_presence_call_set_status (TpConn
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_presence_run_set_status (TpConnection *proxy,
     gint timeout_ms,
     GHashTable *in_Statuses,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_requests_signal_callback_new_channels) (TpConnection *proxy,
@@ -823,13 +1143,15 @@ TpProxyPendingCall *tp_cli_connection_interface_requests_call_create_channel (Tp
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_requests_run_create_channel (TpConnection *proxy,
     gint timeout_ms,
     GHashTable *in_Request,
     gchar **out_Channel,
     GHashTable **out_Properties,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_requests_callback_for_ensure_channel) (TpConnection *proxy,
@@ -847,6 +1169,7 @@ TpProxyPendingCall *tp_cli_connection_interface_requests_call_ensure_channel (Tp
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_requests_run_ensure_channel (TpConnection *proxy,
     gint timeout_ms,
     GHashTable *in_Request,
@@ -854,7 +1177,8 @@ gboolean tp_cli_connection_interface_requests_run_ensure_channel (TpConnection *
     gchar **out_Channel,
     GHashTable **out_Properties,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_simple_presence_signal_callback_presences_changed) (TpConnection *proxy,
@@ -880,12 +1204,14 @@ TpProxyPendingCall *tp_cli_connection_interface_simple_presence_call_set_presenc
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_simple_presence_run_set_presence (TpConnection *proxy,
     gint timeout_ms,
     const gchar *in_Status,
     const gchar *in_Status_Message,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 typedef void (*tp_cli_connection_interface_simple_presence_callback_for_get_presences) (TpConnection *proxy,
@@ -901,12 +1227,14 @@ TpProxyPendingCall *tp_cli_connection_interface_simple_presence_call_get_presenc
     GDestroyNotify destroy,
     GObject *weak_object);
 
+#ifndef TP_DISABLE_DEPRECATED
 gboolean tp_cli_connection_interface_simple_presence_run_get_presences (TpConnection *proxy,
     gint timeout_ms,
     const GArray *in_Contacts,
     GHashTable **out_Presence,
     GError **error,
-    GMainLoop **loop);
+    GMainLoop **loop) _TP_GNUC_DEPRECATED;
+#endif /* not TP_DISABLE_DEPRECATED */
 
 
 G_END_DECLS
