@@ -15,6 +15,34 @@ typedef struct _TpSvcConnection TpSvcConnection;
  * TpSvcConnectionClass:
  *
  * The class of TpSvcConnection.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (connect);
+ *   IMPLEMENT (disconnect);
+ *   IMPLEMENT (get_interfaces);
+ *   IMPLEMENT (get_protocol);
+ *   IMPLEMENT (get_self_handle);
+ *   IMPLEMENT (get_status);
+ *   IMPLEMENT (hold_handles);
+ *   IMPLEMENT (inspect_handles);
+ *   IMPLEMENT (list_channels);
+ *   IMPLEMENT (release_handles);
+ *   IMPLEMENT (request_channel);
+ *   IMPLEMENT (request_handles);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionClass TpSvcConnectionClass;
 
@@ -278,7 +306,7 @@ tp_svc_connection_return_from_request_channel (DBusGMethodInvocation *context,
 
 typedef void (*tp_svc_connection_request_handles_impl) (TpSvcConnection *self,
     guint in_Handle_Type,
-    const gchar **in_Names,
+    const gchar **in_Identifiers,
     DBusGMethodInvocation *context);
 void tp_svc_connection_implement_request_handles (TpSvcConnectionClass *klass, tp_svc_connection_request_handles_impl impl);
 /**
@@ -327,6 +355,26 @@ typedef struct _TpSvcConnectionInterfaceAliasing TpSvcConnectionInterfaceAliasin
  * TpSvcConnectionInterfaceAliasingClass:
  *
  * The class of TpSvcConnectionInterfaceAliasing.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_aliasing (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_aliasing_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (get_alias_flags);
+ *   IMPLEMENT (request_aliases);
+ *   IMPLEMENT (get_aliases);
+ *   IMPLEMENT (set_aliases);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfaceAliasingClass TpSvcConnectionInterfaceAliasingClass;
 
@@ -446,6 +494,29 @@ typedef struct _TpSvcConnectionInterfaceAvatars TpSvcConnectionInterfaceAvatars;
  * TpSvcConnectionInterfaceAvatarsClass:
  *
  * The class of TpSvcConnectionInterfaceAvatars.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_avatars (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_avatars_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (get_avatar_requirements);
+ *   IMPLEMENT (get_avatar_tokens);
+ *   IMPLEMENT (get_known_avatar_tokens);
+ *   IMPLEMENT (request_avatar);
+ *   IMPLEMENT (request_avatars);
+ *   IMPLEMENT (set_avatar);
+ *   IMPLEMENT (clear_avatar);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfaceAvatarsClass TpSvcConnectionInterfaceAvatarsClass;
 
@@ -652,6 +723,38 @@ void tp_svc_connection_interface_avatars_emit_avatar_retrieved (gpointer instanc
     const GArray *arg_Avatar,
     const gchar *arg_Type);
 
+/**
+ * TpSvcConnectionInterfaceBalance:
+ *
+ * Dummy typedef representing any implementation of this interface.
+ */
+typedef struct _TpSvcConnectionInterfaceBalance TpSvcConnectionInterfaceBalance;
+
+/**
+ * TpSvcConnectionInterfaceBalanceClass:
+ *
+ * The class of TpSvcConnectionInterfaceBalance.
+ * This interface has no D-Bus methods, so an
+ * implementation can typically pass %NULL to
+ * G_IMPLEMENT_INTERFACE() as the interface
+ * initialization function.
+ */
+typedef struct _TpSvcConnectionInterfaceBalanceClass TpSvcConnectionInterfaceBalanceClass;
+
+GType tp_svc_connection_interface_balance_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_BALANCE \
+  (tp_svc_connection_interface_balance_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_BALANCE(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_BALANCE, TpSvcConnectionInterfaceBalance))
+#define TP_IS_SVC_CONNECTION_INTERFACE_BALANCE(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_BALANCE))
+#define TP_SVC_CONNECTION_INTERFACE_BALANCE_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_BALANCE, TpSvcConnectionInterfaceBalanceClass))
+
+
+void tp_svc_connection_interface_balance_emit_balance_changed (gpointer instance,
+    const GValueArray *arg_Balance);
+
 /**
  * TpSvcConnectionInterfaceCapabilities:
  *
@@ -663,6 +766,24 @@ typedef struct _TpSvcConnectionInterfaceCapabilities TpSvcConnectionInterfaceCap
  * TpSvcConnectionInterfaceCapabilitiesClass:
  *
  * The class of TpSvcConnectionInterfaceCapabilities.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_capabilities (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_capabilities_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (advertise_capabilities);
+ *   IMPLEMENT (get_capabilities);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfaceCapabilitiesClass TpSvcConnectionInterfaceCapabilitiesClass;
 
@@ -729,6 +850,233 @@ tp_svc_connection_interface_capabilities_return_from_get_capabilities (DBusGMeth
 void tp_svc_connection_interface_capabilities_emit_capabilities_changed (gpointer instance,
     const GPtrArray *arg_Caps);
 
+/**
+ * TpSvcConnectionInterfaceContactCapabilities:
+ *
+ * Dummy typedef representing any implementation of this interface.
+ */
+typedef struct _TpSvcConnectionInterfaceContactCapabilities TpSvcConnectionInterfaceContactCapabilities;
+
+/**
+ * TpSvcConnectionInterfaceContactCapabilitiesClass:
+ *
+ * The class of TpSvcConnectionInterfaceContactCapabilities.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_contact_capabilities (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_contact_capabilities_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (update_capabilities);
+ *   IMPLEMENT (get_contact_capabilities);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
+ */
+typedef struct _TpSvcConnectionInterfaceContactCapabilitiesClass TpSvcConnectionInterfaceContactCapabilitiesClass;
+
+GType tp_svc_connection_interface_contact_capabilities_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES \
+  (tp_svc_connection_interface_contact_capabilities_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES, TpSvcConnectionInterfaceContactCapabilities))
+#define TP_IS_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES))
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_CAPABILITIES, TpSvcConnectionInterfaceContactCapabilitiesClass))
+
+
+typedef void (*tp_svc_connection_interface_contact_capabilities_update_capabilities_impl) (TpSvcConnectionInterfaceContactCapabilities *self,
+    const GPtrArray *in_Handler_Capabilities,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_capabilities_implement_update_capabilities (TpSvcConnectionInterfaceContactCapabilitiesClass *klass, tp_svc_connection_interface_contact_capabilities_update_capabilities_impl impl);
+/**
+ * tp_svc_connection_interface_contact_capabilities_return_from_update_capabilities:
+ * @context: The D-Bus method invocation context
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_capabilities_return_from_update_capabilities (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_capabilities_return_from_update_capabilities (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_capabilities_get_contact_capabilities_impl) (TpSvcConnectionInterfaceContactCapabilities *self,
+    const GArray *in_Handles,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_capabilities_implement_get_contact_capabilities (TpSvcConnectionInterfaceContactCapabilitiesClass *klass, tp_svc_connection_interface_contact_capabilities_get_contact_capabilities_impl impl);
+/**
+ * tp_svc_connection_interface_contact_capabilities_return_from_get_contact_capabilities:
+ * @context: The D-Bus method invocation context
+ * @out_Contact_Capabilities: GHashTable * (FIXME, generate documentation)
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_capabilities_return_from_get_contact_capabilities (DBusGMethodInvocation *context,
+    GHashTable *out_Contact_Capabilities);
+static inline void
+tp_svc_connection_interface_contact_capabilities_return_from_get_contact_capabilities (DBusGMethodInvocation *context,
+    GHashTable *out_Contact_Capabilities)
+{
+  dbus_g_method_return (context,
+      out_Contact_Capabilities);
+}
+
+void tp_svc_connection_interface_contact_capabilities_emit_contact_capabilities_changed (gpointer instance,
+    GHashTable *arg_caps);
+
+/**
+ * TpSvcConnectionInterfaceContactInfo:
+ *
+ * Dummy typedef representing any implementation of this interface.
+ */
+typedef struct _TpSvcConnectionInterfaceContactInfo TpSvcConnectionInterfaceContactInfo;
+
+/**
+ * TpSvcConnectionInterfaceContactInfoClass:
+ *
+ * The class of TpSvcConnectionInterfaceContactInfo.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_contact_info (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_contact_info_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (get_contact_info);
+ *   IMPLEMENT (refresh_contact_info);
+ *   IMPLEMENT (request_contact_info);
+ *   IMPLEMENT (set_contact_info);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
+ */
+typedef struct _TpSvcConnectionInterfaceContactInfoClass TpSvcConnectionInterfaceContactInfoClass;
+
+GType tp_svc_connection_interface_contact_info_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_INFO \
+  (tp_svc_connection_interface_contact_info_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_INFO(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_INFO, TpSvcConnectionInterfaceContactInfo))
+#define TP_IS_SVC_CONNECTION_INTERFACE_CONTACT_INFO(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_INFO))
+#define TP_SVC_CONNECTION_INTERFACE_CONTACT_INFO_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_CONTACT_INFO, TpSvcConnectionInterfaceContactInfoClass))
+
+
+typedef void (*tp_svc_connection_interface_contact_info_get_contact_info_impl) (TpSvcConnectionInterfaceContactInfo *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_info_implement_get_contact_info (TpSvcConnectionInterfaceContactInfoClass *klass, tp_svc_connection_interface_contact_info_get_contact_info_impl impl);
+/**
+ * tp_svc_connection_interface_contact_info_return_from_get_contact_info:
+ * @context: The D-Bus method invocation context
+ * @out_ContactInfo: GHashTable * (FIXME, generate documentation)
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_info_return_from_get_contact_info (DBusGMethodInvocation *context,
+    GHashTable *out_ContactInfo);
+static inline void
+tp_svc_connection_interface_contact_info_return_from_get_contact_info (DBusGMethodInvocation *context,
+    GHashTable *out_ContactInfo)
+{
+  dbus_g_method_return (context,
+      out_ContactInfo);
+}
+
+typedef void (*tp_svc_connection_interface_contact_info_refresh_contact_info_impl) (TpSvcConnectionInterfaceContactInfo *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_info_implement_refresh_contact_info (TpSvcConnectionInterfaceContactInfoClass *klass, tp_svc_connection_interface_contact_info_refresh_contact_info_impl impl);
+/**
+ * tp_svc_connection_interface_contact_info_return_from_refresh_contact_info:
+ * @context: The D-Bus method invocation context
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_info_return_from_refresh_contact_info (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_info_return_from_refresh_contact_info (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+typedef void (*tp_svc_connection_interface_contact_info_request_contact_info_impl) (TpSvcConnectionInterfaceContactInfo *self,
+    guint in_Contact,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_info_implement_request_contact_info (TpSvcConnectionInterfaceContactInfoClass *klass, tp_svc_connection_interface_contact_info_request_contact_info_impl impl);
+/**
+ * tp_svc_connection_interface_contact_info_return_from_request_contact_info:
+ * @context: The D-Bus method invocation context
+ * @out_Contact_Info: const GPtrArray * (FIXME, generate documentation)
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_info_return_from_request_contact_info (DBusGMethodInvocation *context,
+    const GPtrArray *out_Contact_Info);
+static inline void
+tp_svc_connection_interface_contact_info_return_from_request_contact_info (DBusGMethodInvocation *context,
+    const GPtrArray *out_Contact_Info)
+{
+  dbus_g_method_return (context,
+      out_Contact_Info);
+}
+
+typedef void (*tp_svc_connection_interface_contact_info_set_contact_info_impl) (TpSvcConnectionInterfaceContactInfo *self,
+    const GPtrArray *in_ContactInfo,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contact_info_implement_set_contact_info (TpSvcConnectionInterfaceContactInfoClass *klass, tp_svc_connection_interface_contact_info_set_contact_info_impl impl);
+/**
+ * tp_svc_connection_interface_contact_info_return_from_set_contact_info:
+ * @context: The D-Bus method invocation context
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contact_info_return_from_set_contact_info (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_contact_info_return_from_set_contact_info (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_connection_interface_contact_info_emit_contact_info_changed (gpointer instance,
+    guint arg_Contact,
+    const GPtrArray *arg_ContactInfo);
+
 /**
  * TpSvcConnectionInterfaceContacts:
  *
@@ -740,6 +1088,23 @@ typedef struct _TpSvcConnectionInterfaceContacts TpSvcConnectionInterfaceContact
  * TpSvcConnectionInterfaceContactsClass:
  *
  * The class of TpSvcConnectionInterfaceContacts.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_contacts (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_contacts_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (get_contact_attributes);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfaceContactsClass TpSvcConnectionInterfaceContactsClass;
 
@@ -781,6 +1146,122 @@ tp_svc_connection_interface_contacts_return_from_get_contact_attributes (DBusGMe
 }
 
 
+/**
+ * TpSvcConnectionInterfaceLocation:
+ *
+ * Dummy typedef representing any implementation of this interface.
+ */
+typedef struct _TpSvcConnectionInterfaceLocation TpSvcConnectionInterfaceLocation;
+
+/**
+ * TpSvcConnectionInterfaceLocationClass:
+ *
+ * The class of TpSvcConnectionInterfaceLocation.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_location (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_location_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (get_locations);
+ *   IMPLEMENT (request_location);
+ *   IMPLEMENT (set_location);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
+ */
+typedef struct _TpSvcConnectionInterfaceLocationClass TpSvcConnectionInterfaceLocationClass;
+
+GType tp_svc_connection_interface_location_get_type (void);
+#define TP_TYPE_SVC_CONNECTION_INTERFACE_LOCATION \
+  (tp_svc_connection_interface_location_get_type ())
+#define TP_SVC_CONNECTION_INTERFACE_LOCATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_LOCATION, TpSvcConnectionInterfaceLocation))
+#define TP_IS_SVC_CONNECTION_INTERFACE_LOCATION(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_LOCATION))
+#define TP_SVC_CONNECTION_INTERFACE_LOCATION_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TP_TYPE_SVC_CONNECTION_INTERFACE_LOCATION, TpSvcConnectionInterfaceLocationClass))
+
+
+typedef void (*tp_svc_connection_interface_location_get_locations_impl) (TpSvcConnectionInterfaceLocation *self,
+    const GArray *in_Contacts,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_location_implement_get_locations (TpSvcConnectionInterfaceLocationClass *klass, tp_svc_connection_interface_location_get_locations_impl impl);
+/**
+ * tp_svc_connection_interface_location_return_from_get_locations:
+ * @context: The D-Bus method invocation context
+ * @out_Locations: GHashTable * (FIXME, generate documentation)
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_location_return_from_get_locations (DBusGMethodInvocation *context,
+    GHashTable *out_Locations);
+static inline void
+tp_svc_connection_interface_location_return_from_get_locations (DBusGMethodInvocation *context,
+    GHashTable *out_Locations)
+{
+  dbus_g_method_return (context,
+      out_Locations);
+}
+
+typedef void (*tp_svc_connection_interface_location_request_location_impl) (TpSvcConnectionInterfaceLocation *self,
+    guint in_Contact,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_location_implement_request_location (TpSvcConnectionInterfaceLocationClass *klass, tp_svc_connection_interface_location_request_location_impl impl);
+/**
+ * tp_svc_connection_interface_location_return_from_request_location:
+ * @context: The D-Bus method invocation context
+ * @out_Location: GHashTable * (FIXME, generate documentation)
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_location_return_from_request_location (DBusGMethodInvocation *context,
+    GHashTable *out_Location);
+static inline void
+tp_svc_connection_interface_location_return_from_request_location (DBusGMethodInvocation *context,
+    GHashTable *out_Location)
+{
+  dbus_g_method_return (context,
+      out_Location);
+}
+
+typedef void (*tp_svc_connection_interface_location_set_location_impl) (TpSvcConnectionInterfaceLocation *self,
+    GHashTable *in_Location,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_location_implement_set_location (TpSvcConnectionInterfaceLocationClass *klass, tp_svc_connection_interface_location_set_location_impl impl);
+/**
+ * tp_svc_connection_interface_location_return_from_set_location:
+ * @context: The D-Bus method invocation context
+ *
+ * Return successfully by calling dbus_g_method_return().
+ * This inline function exists only to provide type-safety.
+ */
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_location_return_from_set_location (DBusGMethodInvocation *context);
+static inline void
+tp_svc_connection_interface_location_return_from_set_location (DBusGMethodInvocation *context)
+{
+  dbus_g_method_return (context);
+}
+
+void tp_svc_connection_interface_location_emit_location_updated (gpointer instance,
+    guint arg_Contact,
+    GHashTable *arg_Location);
+
 /**
  * TpSvcConnectionInterfacePresence:
  *
@@ -792,6 +1273,30 @@ typedef struct _TpSvcConnectionInterfacePresence TpSvcConnectionInterfacePresenc
  * TpSvcConnectionInterfacePresenceClass:
  *
  * The class of TpSvcConnectionInterfacePresence.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_presence (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_presence_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (add_status);
+ *   IMPLEMENT (clear_status);
+ *   IMPLEMENT (get_presence);
+ *   IMPLEMENT (get_statuses);
+ *   IMPLEMENT (remove_status);
+ *   IMPLEMENT (request_presence);
+ *   IMPLEMENT (set_last_activity_time);
+ *   IMPLEMENT (set_status);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfacePresenceClass TpSvcConnectionInterfacePresenceClass;
 
@@ -987,6 +1492,24 @@ typedef struct _TpSvcConnectionInterfaceRequests TpSvcConnectionInterfaceRequest
  * TpSvcConnectionInterfaceRequestsClass:
  *
  * The class of TpSvcConnectionInterfaceRequests.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_requests (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_requests_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (create_channel);
+ *   IMPLEMENT (ensure_channel);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfaceRequestsClass TpSvcConnectionInterfaceRequestsClass;
 
@@ -1077,6 +1600,24 @@ typedef struct _TpSvcConnectionInterfaceSimplePresence TpSvcConnectionInterfaceS
  * TpSvcConnectionInterfaceSimplePresenceClass:
  *
  * The class of TpSvcConnectionInterfaceSimplePresence.
+ *
+ * In a full implementation of this interface (i.e. all
+ * methods implemented), the interface initialization
+ * function used in G_IMPLEMENT_INTERFACE() would
+ * typically look like this:
+ *
+ * <programlisting>
+ * static void
+ * implement_connection_interface_simple_presence (gpointer klass,
+ *     gpointer unused G_GNUC_UNUSED)
+ * {
+ * #define IMPLEMENT(x) tp_svc_connection_interface_simple_presence_implement_&num;&num;x (\
+ *   klass, my_object_&num;&num;x)
+ *   IMPLEMENT (set_presence);
+ *   IMPLEMENT (get_presences);
+ * #undef IMPLEMENT
+ * }
+ * </programlisting>
  */
 typedef struct _TpSvcConnectionInterfaceSimplePresenceClass TpSvcConnectionInterfaceSimplePresenceClass;
 
