@@ -29,6 +29,7 @@
 #include <telepathy-glib/defs.h>
 #include <telepathy-glib/enums.h>
 #include <telepathy-glib/handle-repo.h>
+#include <telepathy-glib/proxy.h>
 #include <telepathy-glib/svc-connection.h>
 
 G_BEGIN_DECLS
@@ -115,6 +116,16 @@ gboolean tp_base_connection_register (TpBaseConnection *self,
     const gchar *cm_name, gchar **bus_name, gchar **object_path,
     GError **error);
 
+/* FIXME: when dbus-glib exposes its GError -> D-Bus error name mapping,
+we could also add:
+void tp_base_connection_disconnect_with_error (TpBaseConnection *self,
+    const GError *error, GHashTable *details, TpConnectionStatusReason reason);
+*/
+
+void tp_base_connection_disconnect_with_dbus_error (TpBaseConnection *self,
+    const gchar *error_name, GHashTable *details,
+    TpConnectionStatusReason reason);
+
 void tp_base_connection_change_status (TpBaseConnection *self,
     TpConnectionStatus status, TpConnectionStatusReason reason);
 
@@ -182,6 +193,8 @@ gboolean tp_base_connection_channel_manager_iter_next (
       } \
   } G_STMT_END
 
+TpDBusDaemon *tp_base_connection_get_dbus_daemon (TpBaseConnection *self);
+
 G_END_DECLS
 
 #endif /* #ifndef __TP_BASE_CONNECTION_H__*/
