@@ -22,8 +22,9 @@
 #ifndef __TP_CONNECTION_MANAGER_H__
 #define __TP_CONNECTION_MANAGER_H__
 
-#include <telepathy-glib/proxy.h>
 #include <telepathy-glib/dbus.h>
+#include <telepathy-glib/defs.h>
+#include <telepathy-glib/proxy.h>
 
 G_BEGIN_DECLS
 
@@ -32,6 +33,8 @@ typedef struct _TpConnectionManagerClass TpConnectionManagerClass;
 typedef struct _TpConnectionManagerPrivate TpConnectionManagerPrivate;
 
 GType tp_connection_manager_get_type (void);
+GType tp_connection_manager_param_get_type (void);
+GType tp_connection_manager_protocol_get_type (void);
 
 /* TYPE MACROS */
 #define TP_TYPE_CONNECTION_MANAGER \
@@ -50,6 +53,11 @@ GType tp_connection_manager_get_type (void);
   (G_TYPE_INSTANCE_GET_CLASS ((obj), TP_TYPE_CONNECTION_MANAGER, \
                               TpConnectionManagerClass))
 
+#define TP_TYPE_CONNECTION_MANAGER_PARAM \
+  (tp_connection_manager_param_get_type ())
+#define TP_TYPE_CONNECTION_MANAGER_PROTOCOL \
+  (tp_connection_manager_protocol_get_type ())
+
 typedef struct _TpConnectionManagerParam TpConnectionManagerParam;
 struct _TpConnectionManagerParam
 {
@@ -90,7 +98,8 @@ struct _TpConnectionManager {
     /* These are really booleans, but gboolean is signed. Thanks, GLib */
     unsigned int running:1;
     unsigned int always_introspect:1;
-    TpCMInfoSource info_source:2;
+    /* TpCMInfoSource, but can't rely on enums being unsigned */
+    unsigned int info_source:2;
     guint reserved_flags:28;
 
     TpConnectionManagerPrivate *priv;
@@ -103,7 +112,8 @@ struct _TpConnectionManagerClass {
 };
 
 TpConnectionManager *tp_connection_manager_new (TpDBusDaemon *dbus,
-    const gchar *name, const gchar *manager_filename, GError **error);
+    const gchar *name, const gchar *manager_filename, GError **error)
+  G_GNUC_WARN_UNUSED_RESULT;
 
 gboolean tp_connection_manager_activate (TpConnectionManager *self);
 
@@ -135,14 +145,16 @@ gboolean tp_connection_manager_check_valid_name (const gchar *name,
 gboolean tp_connection_manager_check_valid_protocol_name (const gchar *name,
     GError **error);
 
-gchar **tp_connection_manager_dup_protocol_names (TpConnectionManager *self);
+gchar **tp_connection_manager_dup_protocol_names (TpConnectionManager *self)
+  G_GNUC_WARN_UNUSED_RESULT;
 gboolean tp_connection_manager_has_protocol (TpConnectionManager *self,
     const gchar *protocol);
 const TpConnectionManagerProtocol *tp_connection_manager_get_protocol (
     TpConnectionManager *self, const gchar *protocol);
 
 gchar **tp_connection_manager_protocol_dup_param_names (
-    const TpConnectionManagerProtocol *protocol);
+    const TpConnectionManagerProtocol *protocol)
+  G_GNUC_WARN_UNUSED_RESULT;
 gboolean tp_connection_manager_protocol_has_param (
     const TpConnectionManagerProtocol *protocol,
     const gchar *param);
@@ -166,6 +178,20 @@ gboolean tp_connection_manager_param_is_dbus_property (
 gboolean tp_connection_manager_param_get_default (
     const TpConnectionManagerParam *param, GValue *value);
 
+void tp_connection_manager_init_known_interfaces (void);
+
+#define TP_CONNECTION_MANAGER_FEATURE_CORE \
+  (tp_connection_manager_get_feature_quark_core ())
+
+GQuark tp_connection_manager_get_feature_quark_core (void) G_GNUC_CONST;
+
+TpConnectionManagerParam *tp_connection_manager_param_copy (
+    const TpConnectionManagerParam *in);
+void tp_connection_manager_param_free (TpConnectionManagerParam *param);
+TpConnectionManagerProtocol *tp_connection_manager_protocol_copy (
+    const TpConnectionManagerProtocol *in);
+void tp_connection_manager_protocol_free (TpConnectionManagerProtocol *proto);
+
 G_END_DECLS
 
 #include <telepathy-glib/_gen/tp-cli-connection-manager.h>
